import {
  select,
  csv, 
  scaleLinear,  
  max,
  extent,  
  scalePoint,
  axisLeft,
  axisBottom,  
  scaleTime,
  area,
  curveBasis,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Temperature in San Francisco';
  const xAxisLabel = 'Time';
  const yAxisLabel = 'Temperature';
  const xValue = d => d.timestamp;  
  const yValue = d => d.temperature;
  const circle_radius = 10;

  const margin = { top: 40, right: 40, bottom: 80, left: 100};
  const innerwidth = width - margin.left -margin.right;
  const innerheight = height - margin.top -margin.bottom;
  
  const xScale=scaleTime()
  	.domain(extent(data,xValue))
  	.range([0,innerWidth]);
    
  const yScale = scaleLinear()
    .domain(extent(data,yValue))
    .range([innerheight,0])
    .nice(); 
  
  const xAxis = axisBottom(xScale).ticks(6).tickSize(-innerHeight);
  const yAxis = axisLeft(yScale).tickSize(-innerwidth).tickPadding(10);

  const g = svg.append('g')
    .attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0, ${innerheight})`);
  
  const yAxisG = g.append('g').call(yAxis);
      
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class','axis-label')
      .attr('y',60).attr('x',innerwidth/2)
      .attr('fill','black')
      .text(xAxisLabel);
  
  yAxisG.append('text')
      .attr('class','axis-label')
      .attr('y',-50)
      .attr('x',-innerHeight/2 +50)
      .attr('fill','black')
      .attr('transform', `rotate(-90)`) 
      .attr('text-anchor','middle')
      .text(yAxisLabel);

  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)) )
      .attr('cx', d => xScale(xValue(d)) )
      .attr('r', circle_radius);  
  
  g.append('text')
      .attr('class','title')
      .attr('y',-5).attr('x',100)
      .text(title);
  
};



csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
  .then(data => {
	data.forEach( d=>{
    d.timestamp = new Date(d.timestamp);
    d.temperature = +d.temperature;  
  });  
  console.log(data)
  render(data);
});